==> eudplib-0.76.13a10-cp311-abi3-win_amd64.whl: eudplib/core/rawtrigger/strdict/flingy.py <==
#!/usr/bin/python
DefFlingyDict: dict[str, int] = {
    "Scourge": 0,
    "Broodling": 1,
    "Infested Terran": 2,
    "Guardian Cocoon": 3,
    "Defiler": 4,
    "Drone": 5,
    "Egg": 6,
    "Guardian": 7,
    "Hydralisk": 8,
    "Infested Kerrigan": 9,
    "Larva": 10,
    "Mutalisk": 11,
    "Overlord": 12,
    "Queen": 13,
    "Ultralisk": 14,
    "Zergling": 15,
    "Cerebrate": 16,
    "Infested Command Center": 17,
    "Spawning Pool": 18,
    "Mature Chrysalis": 19,
    "Evolution Chamber": 20,
    "Creep Colony": 21,
    "Hatchery": 22,
    "Hive": 23,
    "Lair": 24,
    "Sunken Colony": 25,
    "Greater Spire": 26,
    "Defiler Mound": 27,
    "Queen's Nest": 28,
    "Nydus Canal": 29,
    "Overmind With Shell": 30,
    "Overmind Without Shell": 31,
    "Ultralisk Cavern": 32,
    "Extractor": 33,
    "Hydralisk Den": 34,
    "Spire": 35,
    "Spore Colony": 36,
    "Arbiter": 37,
    "Archon Energy": 38,
    "Carrier": 39,
    "Dragoon": 40,
    "Interceptor": 41,
    "Probe": 42,
    "Scout": 43,
    "Shuttle": 44,
    "High Templar": 45,
    "Dark Templar (Hero)": 46,
    "Reaver": 47,
    "Scarab": 48,
    "Zealot": 49,
    "Observer": 50,
    "Templar Archives": 51,
    "Assimilator": 52,
    "Observatory": 53,
    "Citadel of Adun": 54,
    "Forge": 55,
    "Gateway": 56,
    "Cybernetics Core": 57,
    "Khaydarin Crystal Formation": 58,
    "Nexus": 59,
    "Photon Cannon": 60,
    "Arbiter Tribunal": 61,
    "Pylon": 62,
    "Robotics Facility": 63,
    "Shield Battery": 64,
    "Stargate": 65,
    "Stasis Cell/Prison": 66,
    "Robotics Support Bay": 67,
    "Protoss Temple": 68,
    "Fleet Beacon": 69,
    "Battlecruiser": 70,
    "Civilian": 71,
    "Dropship": 72,
    "Firebat": 73,
    "Ghost": 74,
    "Goliath Base": 75,
    "Goliath Turret": 76,
    "Sarah Kerrigan": 77,
    "Marine": 78,
    "Scanner Sweep": 79,
    "Wraith": 80,
    "SCV": 81,
    "Siege Tank (Tank) Base": 82,
    "Siege Tank (Tank) Turret": 83,
    "Siege Tank (Siege) Base": 84,
    "Siege Tank (Siege) Turret": 85,
    "Science Vessel (Base)": 86,
    "Science Vessel (Turret)": 87,
    "Vulture": 88,
    "Spider Mine": 89,
    "Academy": 90,
    "Barracks": 91,
    "Armory": 92,
    "Comsat Station": 93,
    "Command Center": 94,
    "Supply Depot": 95,
    "Control Tower": 96,
    "Factory": 97,
    "Covert Ops": 98,
    "Ion Cannon": 99,
    "Machine Shop": 100,
    "Missile Turret": 101,
    "Crashed Battlecruiser": 102,
    "Physics Lab": 103,
    "Bunker": 104,
    "Refinery": 105,
    "Immobile Barracks": 106,
    "Science Facility": 107,
    "Nuke Silo": 108,
    "Nuclear Missile": 109,
    "Starport": 110,
    "Engineering Bay": 111,
    "Terran Construction (Large)": 112,
    "Terran Construction (Small)": 113,
    "Ragnasaur": 114,
    "Rhynadon": 115,
    "Bengalaas": 116,
    "Vespene Geyser": 117,
    "Mineral Field Type1": 118,
    "Mineral Field Type2": 119,
    "Mineral Field Type3": 120,
    "Independent Starport": 121,
    "Zerg Beacon": 122,
    "Terran Beacon": 123,
    "Protoss Beacon": 124,
    "Dark Swarm": 125,
    "Flag": 126,
    "Young Chrysalis": 127,
    "Psi Emitter": 128,
    "Data Disc": 129,
    "Khaydarin Crystal": 130,
    "Mineral Chunk Type1": 131,
    "Mineral Chunk Type2": 132,
    "Protoss Gas Orb Type1": 133,
    "Protoss Gas Orb Type2": 134,
    "Zerg Gas Sac Type1": 135,
    "Zerg Gas Sac Type2": 136,
    "Terran Gas Tank Type1": 137,
    "Terran Gas Tank Type2": 138,
    "Map Revealer": 139,
    "Start Location": 140,
    "Fusion Cutter Hit": 141,
    "Gauss Rifle Hit": 142,
    "C-10 Canister Rifle Hit": 143,
    "Gemini Missiles": 144,
    "Fragmentation Grenade": 145,
    "Lockdown/LongBolt/Hellfire Missile": 146,
    "Unused Lockdown": 147,
    "ATS/ATA Laser Battery": 148,
    "Burst Lasers": 149,
    "Arclite Shock Cannon Hit": 150,
    "EMP Missile": 151,
    "Dual Photon Blasters Hit": 152,
    "Particle Beam Hit": 153,
    "Anti-Matter Missile": 154,
    "Pulse Cannon": 155,
    "Psionic Shockwave Hit": 156,
    "Psionic Storm": 157,
    "Yamato Gun": 158,
    "Phase Disruptor": 159,
    "STA/STS Cannon Overlay": 160,
    "Sunken Colony Tentacle": 161,
    "Venom": 162,
    "Acid Spore": 163,
    "Unknown164": 164,
    "Glave Wurm": 165,
    "Seeker Spores": 166,
    "Queen Spell Carrier": 167,
    "Plague Cloud": 168,
    "Consume": 169,
    "Ensnare": 170,
    "Needle Spine Hit": 171,
    "White Circle (Invisible)": 172,
    "Left Upper Level Door": 173,
    "Right Upper Level Door": 174,
    "Substructure Left Door": 175,
    "Substructure Right Door": 176,
    "Substructure Opening Hole": 177,
    "Floor Gun Trap": 178,
    "Floor Missile Trap": 179,
    "Wall Missile Trap": 180,
    "Wall Missile Trap2": 181,
    "Wall Flame Trap": 182,
    "Wall Flame Trap2": 183,
    "Lurker Egg": 184,
    "Devourer": 185,
    "Lurker": 186,
    "Dark Archon Energy": 187,
    "Dark Templar (Unit)": 188,
    "Medic": 189,
    "Valkyrie": 190,
    "Corsair": 191,
    "Disruption Web": 192,
    "Overmind Cocoon": 193,
    "Psi Disrupter": 194,
    "Warp Gate": 195,
    "Power Generator": 196,
    "Xel'Naga Temple": 197,
    "Scantid": 198,
    "Kakaru": 199,
    "Ursadon": 200,
    "Optical Flare Grenade": 201,
    "Halo Rockets": 202,
    "Subterranean Spines": 203,
    "Corrosive Acid Shot": 204,
    "Corrosive Acid Hit": 205,
    "Neutron Flare": 206,
    "Uraj": 207,
    "Khalis": 208,
}

==> eudplib-0.76.14-cp311-abi3-win_amd64.whl: eudplib/core/rawtrigger/strdict/flingy.py <==
#!/usr/bin/python
DefFlingyDict: dict[str, int] = {
    "Scourge": 0,
    "Broodling": 1,
    "Infested Terran": 2,
    "Guardian Cocoon": 3,
    "Defiler": 4,
    "Drone": 5,
    "Egg": 6,
    "Guardian": 7,
    "Hydralisk": 8,
    "Infested Kerrigan": 9,
    "Larva": 10,
    "Mutalisk": 11,
    "Overlord": 12,
    "Queen": 13,
    "Ultralisk": 14,
    "Zergling": 15,
    "Cerebrate": 16,
    "Infested Command Center": 17,
    "Spawning Pool": 18,
    "Mature Chrysalis": 19,
    "Evolution Chamber": 20,
    "Creep Colony": 21,
    "Hatchery": 22,
    "Hive": 23,
    "Lair": 24,
    "Sunken Colony": 25,
    "Greater Spire": 26,
    "Defiler Mound": 27,
    "Queen's Nest": 28,
    "Nydus Canal": 29,
    "Overmind With Shell": 30,
    "Overmind Without Shell": 31,
    "Ultralisk Cavern": 32,
    "Extractor": 33,
    "Hydralisk Den": 34,
    "Spire": 35,
    "Spore Colony": 36,
    "Arbiter": 37,
    "Archon Energy": 38,
    "Carrier": 39,
    "Dragoon": 40,
    "Interceptor": 41,
    "Probe": 42,
    "Scout": 43,
    "Shuttle": 44,
    "High Templar": 45,
    "Dark Templar (Hero)": 46,
    "Reaver": 47,
    "Scarab": 48,
    "Zealot": 49,
    "Observer": 50,
    "Templar Archives": 51,
    "Assimilator": 52,
    "Observatory": 53,
    "Citadel of Adun": 54,
    "Forge": 55,
    "Gateway": 56,
    "Cybernetics Core": 57,
    "Khaydarin Crystal Formation": 58,
    "Nexus": 59,
    "Photon Cannon": 60,
    "Arbiter Tribunal": 61,
    "Pylon": 62,
    "Robotics Facility": 63,
    "Shield Battery": 64,
    "Stargate": 65,
    "Stasis Cell/Prison": 66,
    "Robotics Support Bay": 67,
    "Protoss Temple": 68,
    "Fleet Beacon": 69,
    "Battlecruiser": 70,
    "Civilian": 71,
    "Dropship": 72,
    "Firebat": 73,
    "Ghost": 74,
    "Goliath Base": 75,
    "Goliath Turret": 76,
    "Sarah Kerrigan": 77,
    "Marine": 78,
    "Scanner Sweep": 79,
    "Wraith": 80,
    "SCV": 81,
    "Siege Tank (Tank) Base": 82,
    "Siege Tank (Tank) Turret": 83,
    "Siege Tank (Siege) Base": 84,
    "Siege Tank (Siege) Turret": 85,
    "Science Vessel (Base)": 86,
    "Science Vessel (Turret)": 87,
    "Vulture": 88,
    "Spider Mine": 89,
    "Academy": 90,
    "Barracks": 91,
    "Armory": 92,
    "Comsat Station": 93,
    "Command Center": 94,
    "Supply Depot": 95,
    "Control Tower": 96,
    "Factory": 97,
    "Covert Ops": 98,
    "Ion Cannon": 99,
    "Machine Shop": 100,
    "Missile Turret": 101,
    "Crashed Battlecruiser": 102,
    "Physics Lab": 103,
    "Bunker": 104,
    "Refinery": 105,
    "Immobile Barracks": 106,
    "Science Facility": 107,
    "Nuke Silo": 108,
    "Nuclear Missile": 109,
    "Starport": 110,
    "Engineering Bay": 111,
    "Terran Construction (Large)": 112,
    "Terran Construction (Small)": 113,
    "Ragnasaur": 114,
    "Rhynadon": 115,
    "Bengalaas": 116,
    "Vespene Geyser": 117,
    "Mineral Field Type1": 118,
    "Mineral Field Type2": 119,
    "Mineral Field Type3": 120,
    "Independent Starport": 121,
    "Zerg Beacon": 122,
    "Terran Beacon": 123,
    "Protoss Beacon": 124,
    "Dark Swarm": 125,
    "Flag": 126,
    "Young Chrysalis": 127,
    "Psi Emitter": 128,
    "Data Disc": 129,
    "Khaydarin Crystal": 130,
    "Mineral Chunk Type1": 131,
    "Mineral Chunk Type2": 132,
    "Protoss Gas Orb Type1": 133,
    "Protoss Gas Orb Type2": 134,
    "Zerg Gas Sac Type1": 135,
    "Zerg Gas Sac Type2": 136,
    "Terran Gas Tank Type1": 137,
    "Terran Gas Tank Type2": 138,
    "Map Revealer": 139,
    "Start Location": 140,
    "Fusion Cutter Hit": 141,
    "Gauss Rifle Hit": 142,
    "C-10 Canister Rifle Hit": 143,
    "Gemini Missiles": 144,
    "Fragmentation Grenade": 145,
    "Lockdown/LongBolt/Hellfire Missile": 146,
    "Unused Lockdown": 147,
    "ATS/ATA Laser Battery": 148,
    "Burst Lasers": 149,
    "Arclite Shock Cannon Hit": 150,
    "EMP Missile": 151,
    "Dual Photon Blasters Hit": 152,
    "Particle Beam Hit": 153,
    "Anti-Matter Missile": 154,
    "Pulse Cannon": 155,
    "Psionic Shockwave Hit": 156,
    "Psionic Storm": 157,
    "Yamato Gun": 158,
    "Phase Disruptor": 159,
    "STA/STS Photon Cannon Overlay": 160,
    "Sunken Colony Tentacle": 161,
    "Venom": 162,
    "Acid Spore": 163,
    "Unknown164": 164,
    "Glave Wurm": 165,
    "Seeker Spores": 166,
    "Queen Spell Carrier": 167,
    "Plague Cloud": 168,
    "Consume": 169,
    "Ensnare": 170,
    "Needle Spine Hit": 171,
    "White Circle (Invisible)": 172,
    "Left Upper Level Door": 173,
    "Right Upper Level Door": 174,
    "Substructure Left Door": 175,
    "Substructure Right Door": 176,
    "Substructure Opening Hole": 177,
    "Floor Gun Trap": 178,
    "Floor Missile Trap": 179,
    "Wall Missile Trap": 180,
    "Wall Missile Trap2": 181,
    "Wall Flame Trap": 182,
    "Wall Flame Trap2": 183,
    "Lurker Egg": 184,
    "Devourer": 185,
    "Lurker": 186,
    "Dark Archon Energy": 187,
    "Dark Templar (Unit)": 188,
    "Medic": 189,
    "Valkyrie": 190,
    "Corsair": 191,
    "Disruption Web": 192,
    "Overmind Cocoon": 193,
    "Psi Disrupter": 194,
    "Warp Gate": 195,
    "Power Generator": 196,
    "Xel'Naga Temple": 197,
    "Scantid": 198,
    "Kakaru": 199,
    "Ursadon": 200,
    "Optical Flare Grenade": 201,
    "Halo Rockets": 202,
    "Subterranean Spines": 203,
    "Corrosive Acid Shot": 204,
    "Corrosive Acid Hit": 205,
    "Neutron Flare": 206,
    "Uraj": 207,
    "Khalis": 208,
}
